/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.weekday;

import org.tinygroup.weekday.common.CommonFunction;

import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;

/**
 * 纯日期部分
 * @author luoguo
 *
 */
@XStreamAlias("date")
public final class PureDate implements Comparable<PureDate> {
	@XStreamAsAttribute
	private int year;
	@XStreamAsAttribute
	private int month;
	@XStreamAsAttribute
	private int day;

	public PureDate() {
	}

	public PureDate(int year, int month, int day) {
		this.year = year;
		this.month = month;
		this.day = day;
	}

	public int getYear() {
		return year;
	}

	public void setYear(int year) {
		this.year = year;
	}

	public int getMonth() {
		return month;
	}

	public void setMonth(int month) {
		this.month = month;
	}

	public int getDay() {
		return day;
	}

	public void setDay(int day) {
		this.day = day;
	}

	public int compareTo(PureDate pureDate) {
		int yearCompare = CommonFunction.compare(year, pureDate.year);
		if (yearCompare != 0) {
			return yearCompare;
		}
		int monthCompare = CommonFunction.compare(month, pureDate.month);
		if (monthCompare != 0) {
			return monthCompare;
		}
		return CommonFunction.compare(day, pureDate.day);
	}
}
